# DAITA's Official Python Library

![License: MIT](https://img.shields.io/pypi/l/daita?color=blue) [![PyPi version](https://img.shields.io/pypi/v/daita?color=blue)](https://pypi.org/project/daita) ![Python version support](https://img.shields.io/pypi/pyversions/daita?color=blue)

This is DAITA's official easy-to-use Python library.

## Getting Started

You can install [`daita`](https://pypi.org/project/daita) from PyPI with:

```sh
pip install daita
```

## Contributing

We value feedback and contributions from our community. Whether it's a bug report, new feature, correction, or additional documentation, we welcome your issues and pull requests.
